Index: openssl/ssl/dtls1.h |
=================================================================== |
--- openssl/ssl/dtls1.h (revision 105093) |
+++ openssl/ssl/dtls1.h (working copy) |
@@ -108,15 +108,17 @@ |
typedef struct dtls1_bitmap_st |
{ |
- PQ_64BIT map; |
- unsigned long length; /* sizeof the bitmap in bits */ |
- PQ_64BIT max_seq_num; /* max record number seen so far */ |
+ unsigned long map; /* track 32 packets on 32-bit systems |
+ and 64 - on 64-bit systems */ |
+ unsigned char max_seq_num[8]; /* max record number seen so far, |
+ 64-bit value in big-endian |
+ encoding */ |
} DTLS1_BITMAP; |
struct dtls1_retransmit_state |
{ |
EVP_CIPHER_CTX *enc_write_ctx; /* cryptographic state */ |
- const EVP_MD *write_hash; /* used for mac generation */ |
+ EVP_MD_CTX *write_hash; /* used for mac generation */ |
#ifndef OPENSSL_NO_COMP |
COMP_CTX *compress; /* compression */ |
#else |